Twisted integration with Python Testfixtures
============================================

txfixtures hooks into the testtools 'test fixture' interface, so that you can
write tests that rely on having an external Twisted daemon.

Documentation: http://txfixtures.readthedocs.io/

See:

- https://launchpad.net/txfixtures
- https://launchpad.net/testtools

Licence: GPLv3
